---
title: <span class="badge object-type-scalar"></span> Minutes
---
# <span class="badge object-type-scalar"></span> Minutes

Time: minutes (m)

## Definition

```python
# Time: minutes (m)
Minutes: typing.Literal["m"] = "m"
```
